# Changelog

## 0.1.0 (2025-09-03)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/ElicitLabs/modal-python-sdk/compare/v0.0.1...v0.1.0)

### Features

* **api:** update via SDK Studio ([373dbce](https://github.com/ElicitLabs/modal-python-sdk/commit/373dbceed8aa5cde59951b759c737f31c34ab81c))
* **api:** update via SDK Studio ([2178bdf](https://github.com/ElicitLabs/modal-python-sdk/commit/2178bdff85ce23510c4fbaf1bb1475eeae293d0d))


### Chores

* update SDK settings ([0e0d556](https://github.com/ElicitLabs/modal-python-sdk/commit/0e0d556f761aa830ed1008eafe5789dafc5dab80))
* update SDK settings ([36952f0](https://github.com/ElicitLabs/modal-python-sdk/commit/36952f0edb8bda863589bb4c126d1217d36a91d1))
